@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -52,7 +52,7 @@ public:
     };
 
     explicit ImportWizard(WizardMode mode, QWidget *parent = nullptr);
-    ~ImportWizard();
+    ~ImportWizard() override;
 
     void next() override;
     void reject() override;
