@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -543,7 +543,7 @@ QString EvolutionSettings::getSecurityMethod(const QStringList &listArgument, bo
         return QString();
     }
     for (const QString &str : listArgument) {
-        if (str.contains(QStringLiteral("security-method="))) {
+        if (str.contains(QLatin1String("security-method="))) {
             const int index = str.indexOf(QLatin1String("security-method="));
             if (index != -1) {
                 const QString securityMethod = str.right(str.length() - index - 16 /*security-method=*/);
